pub unsafe extern "C-unwind" fn VNNormalizedPointForImagePoint(
image_point: CGPoint,
image_width: usize,
image_height: usize,
) -> CGPointAvailable on crate features
objc2-core-foundation and VNUtils only.Expand description
Returns a point in normalized coordinate space that is projected from a point in a image coordinates
Parameter imagePoint: The point in image coordinate space.
Parameter imageWidth: The pixel width of the image.
Parameter imageHeight: The pixel height of the image.
Returns: the point in normalized coordinates.