#[repr(transparent)]pub struct VNHumanBodyPose3DObservationHeightEstimation(pub NSInteger);Available on crate feature
VNObservation only.Expand description
Height estimation technique used in observation based on available metadata VNHumanBodyPose3DObservationHeightEstimationReference is the default if no LiDAR depth is present
reference - Since no depth was present, a reference height of 1.8 meters is used
measured - LiDAR depth was used to measure a more accurate bodyHeight in meters
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations