pub unsafe extern "C-unwind" fn VNNormalizedRectIsIdentityRect(
normalized_rect: CGRect,
) -> boolAvailable on crate features
objc2-core-foundation and VNUtils only.Expand description
Determines whether or not the normalized rect describes the identity rect of { {0, 0}, {1, 1} }.
Parameter normalizedRect: The rectangle in the normalized coordinate space of [0..1].
Returns: YES if the rect is the identity rect; otherwise, NO.